@@ -1489,7 +1489,7 @@ Basic Build Instructions for Shotcut
 
 We will not be able to cover everything here, and you are largely on your
 own, but here are some hints. There is a big build bash script that is used
-to make Shotcuts daily builds. It is the authoritative install reference:
+to make Shotcut daily builds. It is the authoritative install reference:
   src/shotcut/scripts/build-shotcut.sh
 
 We cannot cover how to build all of Shotcut's dependencies from scratch here.
@@ -1749,6 +1749,7 @@ function bundle_libs
          ($3 !~ /\/libX11\./) &&
          ($3 !~ /\/libX11-xcb\./) &&
          ($3 !~ /\/libanl\./) &&
+         ($3 !~ /\/libatk-1.0\./) &&
          ($3 !~ /\/libasound\./) &&
          ($3 !~ /\/libc\./) &&
          ($3 !~ /\/libcairo\./) &&
@@ -1902,6 +1903,7 @@ function deploy_mac
     log fixing rpath of executable "$exe"
     cmd install_name_tool -delete_rpath "$FINAL_INSTALL_DIR/lib" "$exe" 2> /dev/null
     cmd install_name_tool -delete_rpath "$QTDIR/lib" "$exe" 2> /dev/null
+    cmd install_name_tool -delete_rpath "/opt/local/lib" "$exe" 2> /dev/null
     cmd install_name_tool -add_rpath "@executable_path/../Frameworks" "$exe"
   done
   cmd cp -p /opt/local/lib/libaom.3.dylib Frameworks
@@ -1913,6 +1915,8 @@ function deploy_mac
   log fixing rpath of executable "whisper-cli"
   cmd install_name_tool -delete_rpath "$SOURCE_DIR"/whisper.cpp/build/src MacOS/whisper-cli 2> /dev/null
   cmd install_name_tool -delete_rpath "$SOURCE_DIR"/whisper.cpp/build/ggml/src MacOS/whisper-cli 2> /dev/null
+  cmd install_name_tool -delete_rpath "$SOURCE_DIR"/whisper.cpp/build/ggml/src/ggml-blas MacOS/whisper-cli 2> /dev/null
+  cmd install_name_tool -delete_rpath "$SOURCE_DIR"/whisper.cpp/build/ggml/src/ggml-metal MacOS/whisper-cli 2> /dev/null
   cmd install_name_tool -add_rpath "@executable_path/../Frameworks" MacOS/whisper-cli
 
   # MLT plugins
