@@ -45,6 +45,7 @@
 #include <QThreadPool>
 #include <QUuid>
 #include <QWidget>
+#include <QtGlobal>
 
 #include <clocale>
 #include <cmath>
@@ -52,10 +53,10 @@
 
 namespace Mlt {
 
-static const int kThumbnailOutSeekFactor = 5;
+static constexpr int kThumbnailOutSeekFactor = 5;
 static Controller *instance = nullptr;
 const QString XmlMimeType("application/vnd.mlt+xml");
-static const char *kMltXmlPropertyName = "string";
+static constexpr char kMltXmlPropertyName[] = "string";
 
 Controller::Controller()
     : m_profile(kDefaultMltProfile)
@@ -65,6 +66,7 @@ Controller::Controller()
     LOG_DEBUG() << "begin";
     ::qputenv("MLT_REPOSITORY_DENY", "libmltqt:libmltglaxnimate");
     m_repo = Mlt::Factory::init();
+    m_processingMode = Settings.processingMode();
     resetLocale();
     initFiltersClipboard();
     updateAvformatCaching(0);
@@ -156,6 +158,11 @@ int Controller::open(const QString &url, const QString &urlToSave, bool skipConv
             if (!channels)
                 channels = 2;
             m_audioChannels = channels;
+            // Load the processing mode
+            QString mode = newProducer->get(kShotcutProjectProcessingMode);
+            if (!mode.isEmpty()) {
+                m_processingMode = Settings.processingModeId(mode);
+            }
         }
         if (Util::isFpsDifferent(profile().fps(), fps)
             || (Settings.playerGPU() && !profile().is_explicit())) {
@@ -482,6 +489,8 @@ bool Controller::saveXML(const QString &filename,
         QString root = withRelativePaths ? QDir::fromNativeSeparators(fi.absolutePath()) : "";
         s.set(kShotcutProjectAudioChannels, m_audioChannels);
         s.set(kShotcutProjectFolder, m_projectFolder.isEmpty() ? 0 : 1);
+        s.set(kShotcutProjectProcessingMode,
+              Settings.processingModeStr(Settings.processingMode()).toUtf8().constData());
         if (!projectNote.isEmpty()) {
             s.set(kShotcutProjectNote, projectNote.toUtf8().constData());
         } else {
@@ -499,9 +508,6 @@ bool Controller::saveXML(const QString &filename,
 
         // Save the consumer of this service so it can be restored.
         auto saveConsumer = mlt_service_consumer(s.consumer()->get_service());
-        if (!saveConsumer) {
-            LOG_ERROR() << "Unable to get save consumer";
-        }
         c.connect(s);
         c.start();
         if (ignore)
@@ -553,9 +559,6 @@ QString Controller::XML(Service *service, bool withProfile, bool withMetadata)
 
     // Save the consumer of this service so it can be restored.
     auto saveConsumer = mlt_service_consumer(s.consumer()->get_service());
-    if (!saveConsumer) {
-        LOG_ERROR() << "Unable to get save consumer";
-    }
     int ignore = s.get_int("ignore_points");
     if (ignore)
         s.set("ignore_points", 0);
@@ -631,7 +634,15 @@ void Controller::setAudioChannels(int audioChannels)
     LOG_DEBUG() << audioChannels;
     if (audioChannels != m_audioChannels) {
         m_audioChannels = audioChannels;
-        restart();
+        consumerChanged();
+    }
+}
+
+void Controller::setProcessingMode(ShotcutSettings::ProcessingMode mode)
+{
+    if (m_processingMode != mode) {
+        m_processingMode = mode;
+        consumerChanged();
     }
 }
 
@@ -881,7 +892,7 @@ void Controller::fixLengthProperties(Service &service)
     parser.start(service);
 }
 
-void Controller::restart(const QString &xml)
+void Controller::reload(const QString &xml)
 {
     if (!m_consumer || !m_consumer->is_valid() || !m_producer || !m_producer->is_valid())
         return;
@@ -1766,6 +1777,33 @@ bool Controller::blockRefresh(bool block)
     return m_blockRefresh;
 }
 
+void Controller::configureHardwareDecoder(bool enable)
+{
+    auto var = "MLT_AVFORMAT_HWACCEL";
+    if (enable) {
+        if (!qEnvironmentVariableIsSet(var)) {
+#if defined(Q_OS_MAC)
+            qputenv(var, "videotoolbox");
+#elif defined(USE_VULKAN)
+            qputenv(var, "vulkan");
+#elif defined(Q_OS_WIN)
+            qputenv(var, "d3d11va");
+#elif defined(Q_OS_LINUX)
+            qputenv(var, "vaapi");
+#endif
+        }
+        var = "MLT_AVFORMAT_HWACCEL_PPS";
+        if (Settings.playerPreviewScale() == 0) {
+            if (!qEnvironmentVariableIsSet(var))
+                qputenv(var, "124416000"); // 1080p60
+        } else {
+            qunsetenv(var);
+        }
+    } else {
+        qunsetenv("MLT_AVFORMAT_HWACCEL");
+    }
+}
+
 void TransportControl::play(double speed)
 {
     MLT.play(speed);
